pub struct Stage {
pub input: MapperInputPort,
pub cursor: SinkCursorPort,
/* private fields */
}Fields
input: MapperInputPortcursor: SinkCursorPortTrait Implementations
Sourceimpl Worker<Stage> for Worker
impl Worker<Stage> for Worker
Sourcefn bootstrap<'life0, 'async_trait>(
_: &'life0 Stage,
) -> Pin<Box<dyn Future<Output = Result<Self, WorkerError>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn bootstrap<'life0, 'async_trait>(
_: &'life0 Stage,
) -> Pin<Box<dyn Future<Output = Result<Self, WorkerError>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Bootstrap a new worker Read more
Sourcefn schedule<'life0, 'life1, 'async_trait>(
&'life0 mut self,
stage: &'life1 mut Stage,
) -> Pin<Box<dyn Future<Output = Result<WorkSchedule<ChainEvent>, WorkerError>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn schedule<'life0, 'life1, 'async_trait>(
&'life0 mut self,
stage: &'life1 mut Stage,
) -> Pin<Box<dyn Future<Output = Result<WorkSchedule<ChainEvent>, WorkerError>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Schedule the next work unit for execution Read more
Sourcefn execute<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
unit: &'life1 ChainEvent,
stage: &'life2 mut Stage,
) -> Pin<Box<dyn Future<Output = Result<(), WorkerError>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn execute<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
unit: &'life1 ChainEvent,
stage: &'life2 mut Stage,
) -> Pin<Box<dyn Future<Output = Result<(), WorkerError>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Execute the action described by the work unit Read more